aboutsummaryrefslogtreecommitdiff
path: root/networking/udhcp/dhcpd.h
diff options
context:
space:
mode:
Diffstat (limited to 'networking/udhcp/dhcpd.h')
-rw-r--r--networking/udhcp/dhcpd.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/networking/udhcp/dhcpd.h b/networking/udhcp/dhcpd.h
index 4b5fcc00f..a3ace92d4 100644
--- a/networking/udhcp/dhcpd.h
+++ b/networking/udhcp/dhcpd.h
@@ -78,9 +78,9 @@ typedef uint32_t leasetime_t;
typedef int32_t signed_leasetime_t;
struct dhcpOfferedAddr {
- uint8_t chaddr[16];
- /* In network order */
- uint32_t yiaddr;
+ uint8_t lease_mac16[16];
+ /* "nip": IP in network order */
+ uint32_t lease_nip;
/* Unix time when lease expires, regardless of value of
* server_config.remaining. Kept in memory in host order.
* When written to file, converted to network order